==> raid_tool-3.1.1.tar.gz: raid_tool-3.1.1/setup.py <==
from setuptools import setup, find_packages

with open("README.md", "r", encoding="utf-8") as fh:
    long_description = fh.read()

setup(
    name="raid-tool",
    version="3.1.1",
    author="Arushi Sharma, Hrishikesha Kyathsandra, Zeynep Oghan",
    author_email="hk.hrishi30@gmail.com",
    description="RAID: Rapid Automated Interpretability Datasets tool",
    long_description=long_description,
    long_description_content_type="text/markdown",
    url="https://github.com/arushisharma17/RAID",
    packages=find_packages(include=['raid', 'raid.*']),  # Only include raid package
    install_requires=[
        "asttokens==2.4.1",
        "attrs==24.2.0",
        "backcall==0.2.0",
        "beautifulsoup4==4.12.3",
        "bleach==6.1.0",
        "blinker==1.8.2",
        "certifi==2024.8.30",
        "charset-normalizer==3.4.0",
        "click==8.1.7",
        "colorama==0.4.6",
        "decorator==5.1.1",
        "defusedxml==0.7.1",
        "docopt==0.6.2",
        "executing==2.1.0",
        "fastjsonschema==2.20.0",
        "Flask==3.0.3",
        "idna==3.10",
        "ipython==8.12.3",
        "itsdangerous==2.2.0",
        "jedi==0.19.1",
        "Jinja2==3.1.4",
        "jsonschema==4.23.0",
        "jsonschema-specifications==2024.10.1",
        "jupyter_client==8.6.3",
        "jupyter_core==5.7.2",
        "jupyterlab_pygments==0.3.0",
        "MarkupSafe==2.1.5",
        "matplotlib-inline==0.1.7",
        "mistune==3.0.2",
        "nbclient==0.10.0",
        "nbconvert==7.16.4",
        "nbformat==5.10.4",
        "packaging==24.1",
        "pandocfilters==1.5.1",
        "parso==0.8.4",
        "pickleshare==0.7.5",
        "pipreqs==0.5.0",
        "platformdirs==4.3.6",
        "prompt_toolkit==3.0.48",
        "pure_eval==0.2.3",
        "Pygments==2.18.0",
        "python-dateutil==2.9.0.post0",
        "pywin32==308;platform_system=='Windows'", 
        "pyzmq==26.2.0",
        "referencing==0.35.1",
        "requests==2.32.3",
        "rpds-py==0.20.0",
        "six==1.16.0",
        "soupsieve==2.6",
        "stack-data==0.6.3",
        "tinycss2==1.3.0",
        "tornado==6.4.1",
        "traitlets==5.14.3",
        "urllib3==2.2.3",
        "wcwidth==0.2.13",
        "webencodings==0.5.1",
        "Werkzeug==3.0.4",
        "yarg==0.1.9",
        "contourpy==1.3.0",
        "cycler==0.12.1",
        "dill==0.3.4",
        "filelock==3.16.1",
        "fonttools==4.54.1",
        "fsspec==2024.9.0",
        "graphviz==0.20.3",
        "h5py==3.12.1",
        "huggingface-hub==0.25.1",
        "imbalanced-learn==0.12.4",
        "joblib==1.4.2",
        "kiwisolver==1.4.7",
        "matplotlib==3.9.2",
        "memory-profiler==0.61.0",
        "mpmath==1.3.0",
        "networkx==3.3",
        "numpy==1.26.4",
        "pandas==2.2.3",
        "pillow==10.4.0",
        "psutil==6.0.0",
        "pyparsing==3.1.4",
        "pytz==2024.2",
        "PyYAML==6.0.2",
        "regex==2024.9.11",
        "safetensors==0.4.5",
        "scikit-learn==1.5.2",
        "scipy==1.14.1",
        "seaborn==0.11.1",
        "svgwrite==1.4.1",
        "sympy==1.13.3",
        "threadpoolctl==3.5.0",
        "tokenizers==0.20.0",
        "torch==2.4.1",
        "tqdm==4.66.5",
        "transformers==4.45.1",
        "tree-sitter==0.23.0",
        "tree-sitter-java==0.23.2",
        "tree-sitter-python==0.23.2",
        "typing_extensions==4.12.2",
        "tzdata==2024.2",
    ],
    dependency_links=[
        "git+https://github.com/arushisharma17/NeuroX.git@fe7ab9c2d8eb1b4b3f93de73b8eaae57a6fc67b7#egg=neurox"
    ],
    entry_points={
        'console_scripts': [
            'raid=raid.raid_pipeline:main',
        ],
    },
    python_requires=">=3.6",
    classifiers=[
        "Programming Language :: Python :: 3",
        "License :: OSI Approved :: MIT License",
        "Operating System :: OS Independent",
    ],
)

==> raid_tool-3.1.4.tar.gz: raid_tool-3.1.4/setup.py <==
from setuptools import setup, find_packages

with open("README.md", "r", encoding="utf-8") as fh:
    long_description = fh.read()

setup(
    name="raid-tool",
    version="3.1.4",
    author="Hrishikesha Kyathsandra, Zeynep Oghan, Arushi Sharma",
    author_email="hk.hrishi30@gmail.com",
    description="RAID: Rapid Automated Interpretability Datasets tool",
    long_description=long_description,
    long_description_content_type="text/markdown",
    url="https://github.com/arushisharma17/RAID",
    packages=find_packages(include=['raid', 'raid.*']),  
    install_requires=[
        "asttokens==2.4.1",
        "attrs==24.2.0",
        "backcall==0.2.0",
        "beautifulsoup4==4.12.3",
        "bleach==6.1.0",
        "blinker==1.8.2",
        "certifi==2024.8.30",
        "charset-normalizer==3.4.0",
        "click==8.1.7",
        "colorama==0.4.6",
        "decorator==5.1.1",
        "defusedxml==0.7.1",
        "docopt==0.6.2",
        "executing==2.1.0",
        "fastjsonschema==2.20.0",
        "Flask==3.0.3",
        "idna==3.10",
        "ipython==8.12.3",
        "itsdangerous==2.2.0",
        "jedi==0.19.1",
        "Jinja2==3.1.4",
        "jsonschema==4.23.0",
        "jsonschema-specifications==2024.10.1",
        "jupyter_client==8.6.3",
        "jupyter_core==5.7.2",
        "jupyterlab_pygments==0.3.0",
        "MarkupSafe==2.1.5",
        "matplotlib-inline==0.1.7",
        "mistune==3.0.2",
        "nbclient==0.10.0",
        "nbconvert==7.16.4",
        "nbformat==5.10.4",
        "packaging==24.1",
        "pandocfilters==1.5.1",
        "parso==0.8.4",
        "pickleshare==0.7.5",
        "pipreqs==0.5.0",
        "platformdirs==4.3.6",
        "prompt_toolkit==3.0.48",
        "pure_eval==0.2.3",
        "Pygments==2.18.0",
        "python-dateutil==2.9.0.post0",
        "pywin32==308;platform_system=='Windows'", 
        "pyzmq==26.2.0",
        "referencing==0.35.1",
        "requests==2.32.3",
        "rpds-py==0.20.0",
        "six==1.16.0",
        "soupsieve==2.6",
        "stack-data==0.6.3",
        "tinycss2==1.3.0",
        "tornado==6.4.1",
        "traitlets==5.14.3",
        "urllib3==2.2.3",
        "wcwidth==0.2.13",
        "webencodings==0.5.1",
        "Werkzeug==3.0.4",
        "yarg==0.1.9",
        "contourpy==1.3.0",
        "cycler==0.12.1",
        "dill==0.3.4",
        "filelock==3.16.1",
        "fonttools==4.54.1",
        "fsspec==2024.9.0",
        "graphviz==0.20.3",
        "h5py==3.12.1",
        "huggingface-hub==0.25.1",
        "imbalanced-learn==0.12.4",
        "joblib==1.4.2",
        "kiwisolver==1.4.7",
        "matplotlib==3.9.2",
        "memory-profiler==0.61.0",
        "mpmath==1.3.0",
        "networkx==3.3",
        "numpy==1.26.4",
        "pandas==2.2.3",
        "pillow==10.4.0",
        "psutil==6.0.0",
        "pyparsing==3.1.4",
        "pytz==2024.2",
        "PyYAML==6.0.2",
        "regex==2024.9.11",
        "safetensors==0.4.5",
        "scikit-learn==1.5.2",
        "scipy==1.14.1",
        "seaborn==0.11.1",
        "svgwrite==1.4.1",
        "sympy==1.13.3",
        "threadpoolctl==3.5.0",
        "tokenizers==0.20.0",
        "torch==2.4.1",
        "tqdm==4.66.5",
        "transformers==4.45.1",
        "tree-sitter==0.23.0",
        "tree-sitter-java==0.23.2",
        "tree-sitter-python==0.23.2",
        "typing_extensions==4.12.2",
        "tzdata==2024.2",
    ],
    dependency_links=[
        "git+https://github.com/arushisharma17/NeuroX.git@fe7ab9c2d8eb1b4b3f93de73b8eaae57a6fc67b7#egg=neurox"
    ],
    entry_points={
        'console_scripts': [
            'raid=raid.raid_pipeline:main',
        ],
    },
    python_requires=">=3.6",
    classifiers=[
        "Programming Language :: Python :: 3",
        "License :: OSI Approved :: MIT License",
        "Operating System :: OS Independent",
    ],
)
